@@ -1,6 +1,5 @@
-# Copyright (C) 2007-2018 David Aguilar and contributors
-"""This module provides miscellaneous utility functions."""
-from __future__ import division, absolute_import, unicode_literals
+"""Miscellaneous utility functions"""
+from __future__ import absolute_import, division, print_function, unicode_literals
 import copy
 import os
 import random
@@ -148,16 +147,12 @@ def dirname(path, current_dir=''):
 
 
 def splitpath(path):
-    """Split paths using '/' regardless of platform
-
-    """
+    """Split paths using '/' regardless of platform"""
     return path.split('/')
 
 
 def join(*paths):
-    """Join paths using '/' regardless of platform
-
-    """
+    """Join paths using '/' regardless of platform"""
     return '/'.join(paths)
 
 
