@@ -1,5 +1,5 @@
 # encoding: utf-8
-from __future__ import division, absolute_import, unicode_literals
+from __future__ import absolute_import, division, print_function, unicode_literals
 import platform
 import webbrowser
 import sys
@@ -284,102 +284,108 @@ def authors_text():
         ),
         dict(name='Efimov Vasily', title=N_('Developer')),
         dict(name='Guillaume de Bure', title=N_('Developer')),
-        dict(name='Javier Rodriguez Cuevas', title=N_('Developer')),
         dict(name='Uri Okrent', title=N_('Developer')),
+        dict(name='Javier Rodriguez Cuevas', title=N_('Developer')),
         dict(name='Alex Chernetz', title=N_('Developer')),
         dict(name='xhl', title=N_('Developer')),
         dict(name='Andreas Sommer', title=N_('Developer')),
         dict(name='Thomas Kluyver', title=N_('Developer')),
         dict(name='Minarto Margoliono', title=N_('Developer')),
-        dict(name='Szymon Judasz', title=N_('Developer')),
         dict(name='Ville Skyttä', title=N_('Developer')),
+        dict(name='Szymon Judasz', title=N_('Developer')),
         dict(name='jm4R', title=N_('Developer')),
-        dict(name='Igor Galarraga', title=N_('Developer')),
         dict(name='Stanislaw Halik', title=N_('Developer')),
+        dict(name='Igor Galarraga', title=N_('Developer')),
         dict(name='Virgil Dupras', title=N_('Developer')),
-        dict(name='Barry Roberts', title=N_('Developer')),
         dict(name='wsdfhjxc', title=N_('Developer')),
+        dict(name='Barry Roberts', title=N_('Developer')),
         dict(name='林博仁(Buo-ren Lin)', title=N_('Developer')),
         dict(name='Guo Yunhe', title=N_('Developer')),
         dict(name='cclauss', title=N_('Developer')),
         dict(name='Stefan Naewe', title=N_('Developer')),
         dict(name='Victor Nepveu', title=N_('Developer')),
+        dict(name='Pavel Rehak', title=N_('Developer')),
         dict(name='Benedict Lee', title=N_('Developer')),
+        dict(name='Tim Brown', title=N_('Developer')),
+        dict(name='Steffen Prohaska', title=N_('Developer')),
         dict(name='Filip Danilović', title=N_('Developer')),
         dict(name='NotSqrt', title=N_('Developer')),
-        dict(name='Pavel Rehak', title=N_('Developer')),
-        dict(name='Steffen Prohaska', title=N_('Developer')),
-        dict(name='Tim Brown', title=N_('Developer')),
         dict(name='Michael Geddes', title=N_('Developer')),
         dict(name='Rustam Safin', title=N_('Developer')),
+        dict(name='Justin Lecher', title=N_('Developer')),
         dict(name='Alex Gulyás', title=N_('Developer')),
         dict(name='David Martínez Martí', title=N_('Developer')),
         dict(name='Hualiang Xie', title=N_('Developer')),
-        dict(name='Justin Lecher', title=N_('Developer')),
         dict(name='Kai Krakow', title=N_('Developer')),
         dict(name='Karl Bielefeldt', title=N_('Developer')),
         dict(name='Marco Costalba', title=N_('Developer')),
         dict(name='Michael Homer', title=N_('Developer')),
         dict(name='Sebastian Schuberth', title=N_('Developer')),
         dict(name='Sven Claussner', title=N_('Developer')),
+        dict(name='Victor Gambier', title=N_('Developer')),
         dict(name='bsomers', title=N_('Developer')),
         dict(name='real', title=N_('Developer')),
         dict(name='v.paritskiy', title=N_('Developer')),
-        dict(name='0xflotus', title=N_('Developer')),
-        dict(name='AJ Bagwell', title=N_('Developer')),
-        dict(name='Adrien be', title=N_('Developer')),
-        dict(name='Andrej', title=N_('Developer')),
-        dict(name='Arthur Coelho', title=N_('Developer')),
+        dict(name='vanderkoort', title=N_('Developer')),
+        dict(name='wm4', title=N_('Developer')),
         dict(name='Audrius Karabanovas', title=N_('Developer')),
-        dict(name='Barrett Lowe', title=N_('Developer')),
-        dict(name='Ben Boeckel', title=N_('Developer')),
-        dict(name='Boris W', title=N_('Developer')),
-        dict(name='Charles', title=N_('Developer')),
-        dict(name='Clément Pit--Claudel', title=N_('Developer')),
-        dict(name='Daniel Haskin', title=N_('Developer')),
-        dict(name='Daniel King', title=N_('Developer')),
-        dict(name='Daniel Pavel', title=N_('Developer')),
-        dict(name='David Zumbrunnen', title=N_('Developer')),
-        dict(name='Felipe Morales', title=N_('Developer')),
-        dict(name='George Vasilakos', title=N_('Developer')),
-        dict(name='Ilya Tumaykin', title=N_('Developer')),
-        dict(name='Iulian Udrea', title=N_('Developer')),
-        dict(name='Jake Biesinger', title=N_('Developer')),
-        dict(name='Jakub Szymański', title=N_('Developer')),
-        dict(name='Jamie Pate', title=N_('Developer')),
-        dict(name='Jean-Francois Dagenais', title=N_('Developer')),
-        dict(name='Joachim Lusiardi', title=N_('Developer')),
-        dict(name='Karthik Manamcheri', title=N_('Developer')),
-        dict(name='Kelvie Wong', title=N_('Developer')),
-        dict(name='Kyle', title=N_('Developer')),
-        dict(name='Maciej Filipiak', title=N_('Developer')),
-        dict(name='Maicon D. Filippsen', title=N_('Developer')),
-        dict(name='Markus Heidelberg', title=N_('Developer')),
         dict(name='Matthew E. Levine', title=N_('Developer')),
         dict(name='Matthias Mailänder', title=N_('Developer')),
         dict(name='Md. Mahbub Alam', title=N_('Developer')),
+        dict(name='Jakub Szymański', title=N_('Developer')),
+        dict(name='ochristi', title=N_('Developer')),
+        dict(name='Miguel Boekhold', title=N_('Developer')),
+        dict(name='MiguelBoekhold', title=N_('Developer')),
         dict(name='Mikhail Terekhov', title=N_('Developer')),
+        dict(name='Jake Biesinger', title=N_('Developer')),
+        dict(name='Iulian Udrea', title=N_('Developer')),
         dict(name='Paul Hildebrandt', title=N_('Developer')),
         dict(name='Paul Weingardt', title=N_('Developer')),
         dict(name='Paulo Fidalgo', title=N_('Developer')),
+        dict(name='Ilya Tumaykin', title=N_('Developer')),
         dict(name='Petr Gladkikh', title=N_('Developer')),
         dict(name='Philip Stark', title=N_('Developer')),
         dict(name='Radek Postołowicz', title=N_('Developer')),
         dict(name='Rainer Müller', title=N_('Developer')),
         dict(name='Ricardo J. Barberis', title=N_('Developer')),
         dict(name='Rolando Espinoza', title=N_('Developer')),
+        dict(name='George Vasilakos', title=N_('Developer')),
         dict(name="Samsul Ma'arif", title=N_('Developer')),
         dict(name='Sebastian Brass', title=N_('Developer')),
+        dict(name='Arthur Coelho', title=N_('Developer')),
         dict(name='Simon Peeters', title=N_('Developer')),
+        dict(name='Felipe Morales', title=N_('Developer')),
+        dict(name='David Zumbrunnen', title=N_('Developer')),
+        dict(name='David Schwörer', title=N_('Developer')),
         dict(name='Stephen', title=N_('Developer')),
+        dict(name='Andrej', title=N_('Developer')),
+        dict(name='Daniel Pavel', title=N_('Developer')),
+        dict(name='Daniel King', title=N_('Developer')),
+        dict(name='Daniel Haskin', title=N_('Developer')),
+        dict(name='Clément Pit--Claudel', title=N_('Developer')),
         dict(name='Vaibhav Sagar', title=N_('Developer')),
         dict(name='Ved Vyas', title=N_('Developer')),
+        dict(name='Adrien be', title=N_('Developer')),
+        dict(name='Charles', title=N_('Developer')),
+        dict(name='Boris W', title=N_('Developer')),
+        dict(name='Ben Boeckel', title=N_('Developer')),
         dict(name='Voicu Hodrea', title=N_('Developer')),
         dict(name='Wesley Wong', title=N_('Developer')),
         dict(name='Wolfgang Ocker', title=N_('Developer')),
         dict(name='Zhang Han', title=N_('Developer')),
         dict(name='beauxq', title=N_('Developer')),
-        dict(name='ochristi', title=N_('Developer')),
+        dict(name='Jamie Pate', title=N_('Developer')),
+        dict(name='Jean-Francois Dagenais', title=N_('Developer')),
+        dict(name='Joachim Lusiardi', title=N_('Developer')),
+        dict(name='0xflotus', title=N_('Developer')),
+        dict(name='AJ Bagwell', title=N_('Developer')),
+        dict(name='Barrett Lowe', title=N_('Developer')),
+        dict(name='Karthik Manamcheri', title=N_('Developer')),
+        dict(name='Kelvie Wong', title=N_('Developer')),
+        dict(name='Kyle', title=N_('Developer')),
+        dict(name='Maciej Filipiak', title=N_('Developer')),
+        dict(name='Maicon D. Filippsen', title=N_('Developer')),
+        dict(name='Markus Heidelberg', title=N_('Developer')),
     )
     bug_url = 'https://github.com/git-cola/git-cola/issues'
     bug_link = link(bug_url, bug_url)
@@ -411,19 +417,21 @@ def translators_text():
             email=mailto('Vdragon.Taiwan@gmail.com', contact, palette),
         ),
         dict(name='Pavel Rehak', title=N_('Czech translation')),
+        dict(name='Zhang Han', title=N_('Simplified Chinese translation')),
         dict(name='Victorhck', title=N_('Spanish translation')),
         dict(name='Vitor Lobo', title=N_('Brazilian translation')),
-        dict(name='Zhang Han', title=N_('Simplified Chinese translation')),
         dict(name='Igor Kopach', title=N_('Ukranian translation')),
-        dict(name='Barış ÇELİK', title=N_('Turkish translation')),
-        dict(name='Guo Yunhe', title=N_('Simplified Chinese translation')),
-        dict(name='Minarto Margoliono', title=N_('Indonesian translation')),
+        dict(name='Łukasz Wojniłowicz', title=N_('Polish translation')),
         dict(name='Rafael Nascimento', title=N_('Brazilian translation')),
-        dict(name='Shun Sakai', title=N_('Japanese translation')),
+        dict(name='Barış ÇELİK', title=N_('Turkish translation')),
+        dict(name='Minarto Margoliono', title=N_('Indonesian translation')),
         dict(name='Sven Claussner', title=N_('German translation')),
+        dict(name='Shun Sakai', title=N_('Japanese translation')),
         dict(name='Vaiz', title=N_('Russian translation')),
         dict(name='adlgrbz', title=N_('Turkish translation')),
         dict(name='fu7mu4', title=N_('Japanese translation')),
+        dict(name='Guo Yunhe', title=N_('Simplified Chinese translation')),
+        dict(name="Samsul Ma'arif", title=N_('Indonesian translation')),
         dict(name='Gyuris Gellért', title=N_('Hungarian translation')),
         dict(name='Joachim Lusiardi', title=N_('German translation')),
         dict(name='Kai Krakow', title=N_('German translation')),
@@ -436,11 +444,10 @@ def translators_text():
         dict(name='Pilar Molina Lopez', title=N_('Spanish translation')),
         dict(name='Rafael Reuber', title=N_('Brazilian translation')),
         dict(name='Sabri Ünal', title=N_('Turkish translation')),
-        dict(name="Samsul Ma'arif", title=N_('Indonesian translation')),
+        dict(name='Balázs Meskó', title=N_('Translation')),
         dict(name='Zeioth', title=N_('Spanish translation')),
         dict(name='balping', title=N_('Hungarian translation')),
         dict(name='p-bo', title=N_('Czech translation')),
-        dict(name='Łukasz Wojniłowicz', title=N_('Polish translation')),
         dict(
             name='林博仁(Buo-ren Lin)',
             title=N_('Traditional Chinese (Taiwan) translation'),
