@@ -1,5 +1,5 @@
 """Provides widgets related to bookmarks"""
-from __future__ import division, absolute_import, unicode_literals
+from __future__ import absolute_import, division, print_function, unicode_literals
 import os
 
 from qtpy import QtCore
